@@ -13,7 +13,7 @@ use HTTP::Tiny;
 use parent qw( EPublisher::Source::Base );
 
 
-our $VERSION = '0.6_01';
+our $VERSION = '0.6_02';
 our $UA;
 
 # implementing the interface to EPublisher::Source::Base
@@ -43,7 +43,7 @@ sub _get_pod {
         'http://perltuts.com/tutorials/' . $name . '?format=pod'
     );
 
-    if ( $response !~ m{\A2} ) {
+    if ( $response->{status} !~ m{\A2} ) {
         $self->publisher->debug(
             "103: tutorial $name does not exist"
         );
@@ -81,7 +81,7 @@ sub _get_pod {
 }
 
 sub ua {
-    $UA //= HTTP::Tiny->new;
+    $UA = HTTP::Tiny->new if !$UA;
     $UA;
 }
 
@@ -99,7 +99,7 @@ EPublisher::Source::Plugin::PerltutsCom - Get POD from tutorials published on pe
 
 =head1 VERSION
 
-version 0.6_01
+version 0.6_02
 
 =head1 SYNOPSIS
 
